package com.ruoyi.ss.channel.service.impl;

import com.ruoyi.common.auth.ali.AliConfig;
import com.ruoyi.common.pay.tm.config.TmPayConfig;
import com.ruoyi.common.pay.wx.config.WxPayConfig;
import com.ruoyi.common.pay.xy.config.XyPayConfig;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.ss.app.domain.AppConfig;
import com.ruoyi.ss.app.domain.AppVO;
import com.ruoyi.ss.channel.domain.ChannelConfig;
import com.ruoyi.ss.channel.domain.ChannelVO;
import com.ruoyi.ss.channel.domain.enums.ChannelApiType;
import com.ruoyi.ss.channel.service.ChannelConverter;
import org.springframework.stereotype.Service;

/**
 * @author wjh
 * 2025/1/7
 */
@Service
public class ChannelConverterImpl implements ChannelConverter {

    private static final String WX_NOTIFY_URL = SpringUtils.getRequiredProperty("wx.pay.notifyUrl");
    private static final String WX_REFUND_NOTIFY_URL = SpringUtils.getRequiredProperty("wx.pay.refundNotifyUrl");
    private static final String ALI_NOTIFY_URL = SpringUtils.getRequiredProperty("ali.notifyUrl");
    private static final String ALI_TRANSFER_NOTIFY_URL = SpringUtils.getRequiredProperty("ali.transferNotifyUrl");
    private static final String TM_NOTIFY_URL = SpringUtils.getRequiredProperty("tm.notifyUrl");
    private static final String XY_NOTIFY_URL = SpringUtils.getRequiredProperty("xy.notifyUrl");

    @Override
    public Object toConfig(ChannelVO channel, AppVO app) {
        if (channel == null || channel.getChannelConfig() == null) {
            return null;
        }
        if (app == null) {
            app = new AppVO();
        }

        ChannelConfig channelConfig = channel.getChannelConfig();
        AppConfig appConfig = app.getConfig() == null ? new AppConfig() : app.getConfig();

        // 微信
        if (ChannelApiType.WECHAT.getType().equals(channel.getApiType())) {
            WxPayConfig config = new WxPayConfig();
            config.setAppId(appConfig.getAppId());
            config.setMerchantId(channelConfig.getMerchantId());
            config.setApiV3Key(channelConfig.getApiV3Key());
            config.setNotifyUrl(WX_NOTIFY_URL);
            config.setRefundNotifyUrl(WX_REFUND_NOTIFY_URL);
            config.setPrivateKeyPath(channelConfig.getPrivateKeyPath());
            config.setMerchantSerialNumber(channelConfig.getMerchantSerialNumber());
            return config;
        }
        // 支付宝
        else if (ChannelApiType.ALI.getType().equals(channel.getApiType())) {
            AliConfig config = new AliConfig();
            config.setAppId(appConfig.getAppId());
            config.setPrivateKey(appConfig.getPrivateKey());
            config.setAesPrivateKey(appConfig.getAesPrivateKey());
            config.setNotifyUrl(ALI_NOTIFY_URL + "/" + app.getId());
            config.setTransferNotifyUrl(ALI_TRANSFER_NOTIFY_URL + "/" + app.getId());
            config.setAppCertPath(appConfig.getAppCertPath());
            config.setAlipayCertPath(appConfig.getAlipayCertPath());
            config.setAlipayRootCertPath(appConfig.getAlipayRootCertPath());
            return config;
        }
        // 太米
        else if (ChannelApiType.TM_WX.getType().equals(channel.getApiType())) {
            TmPayConfig config = new TmPayConfig();
            config.setDeveloperId(channelConfig.getDeveloperId());
            config.setShopId(channelConfig.getShopId());
            config.setSignKey(channelConfig.getSignKey());
            config.setHttpUrl(channelConfig.getHttpUrl());
            config.setSn(channelConfig.getSn());
            config.setNotifyUrl(TM_NOTIFY_URL + "/" + channel.getChannelId());
            return config;
        }
        // 国通星驿
        else if (ChannelApiType.XY_WX.getType().equals(channel.getApiType())) {
            XyPayConfig config = new XyPayConfig();
            config.setAppId(appConfig.getAppId());
            config.setPublicKey(channelConfig.getPublicKey());
            config.setAgetId(channelConfig.getAgetId());
            config.setCustId(channelConfig.getCustId());
            config.setHost(channelConfig.getHost());
            config.setNotifyUrl(XY_NOTIFY_URL + "/" + channel.getChannelId());
            return config;
        }

        return null;
    }
}
